% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotAbundanceDensity.R
\name{plotAbundanceDensity}
\alias{plotAbundanceDensity}
\alias{plotAbundanceDensity,SummarizedExperiment-method}
\title{Plot abundance density}
\usage{
plotAbundanceDensity(object, ...)

\S4method{plotAbundanceDensity}{SummarizedExperiment}(
  object,
  layout = c("jitter", "density", "point"),
  abund_values = "counts",
  n = min(nrow(object), 25L),
  colour_by = NULL,
  shape_by = NULL,
  size_by = NULL,
  order_descending = TRUE,
  ...
)
}
\arguments{
\item{object}{a
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
object.}

\item{...}{additional parameters for plotting.
\itemize{
\item{xlab}{ a single character value for selecting the x-axis label.
(default: \code{xlab = abund_values}) }

\item{ylab}{ a single character value for selecting the y-axis label.
\code{ylab} is disabled when \code{layout = "density"}.
(default: \code{ylab = "Taxa")} }

\item{point_alpha}{ a numeric value from range 0 to 1 selecting the transparency of
colour in \code{jitter} and \code{point} plot. (default: \code{point_alpha = 0.6}) }

\item{point_shape}{ a positive integer value selecting the shape of point in
\code{jitter} and \code{point} plot. (default: \code{point_shape = 21}) }

\item{point_size}{ a positive numeric value selecting the size of point in
\code{jitter} and \code{point} plot. (default: \code{point_size = 2}) }

\item{add_legend}{ a boolean value selecting if legend is added.
(default: \code{add_legend = TRUE}) }

\item{flipped}{ a boolean value selecting if the orientation of plot is changed
so that x-axis and y-axis are swapped. (default \code{flipped = FALSE}) }

\item{add_x_text}{ a boolean value selecting if text that represents values is included
in x-axis. (default: \code{add_x_text = TRUE}) }

}
See \code{\link{mia-plot-args}} for more details i.e. call \code{help("mia-plot-args")}}

\item{layout}{a single character value for selecting the layout of the plot.
There are three different options: \code{jitter}, \code{density}, and
\code{point} plot. (default: \code{layout = "jitter"})}

\item{abund_values}{a single character value for selecting the
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{assay}} to be
plotted. (default: \code{abund_values = "counts"})}

\item{n}{a positive integer specifying the number of the most abundant taxa
to show. (default: \code{n = min(nrow(object), 25L)})}

\item{colour_by}{a single character value defining a column from
\code{colData}, that is used to color plot. Must be a value of
\code{colData()} function. (default: \code{colour_by = NULL})}

\item{shape_by}{a single character value defining a column from
\code{colData}, that is used to group observations to different point shape
groups. Must be a value of \code{colData()} function. \code{shape_by} is
disabled when \code{layout = "density"}. (default: \code{shape_by = NULL})}

\item{size_by}{a single character value defining a column from
\code{colData}, that is used to group observations to different point size
groups. Must be a value of \code{colData()} function. \code{size_by} is
disabled when \code{layout = "density"}. (default: \code{size_by = NULL})}

\item{order_descending}{\code{TRUE}, \code{FALSE} or\code{NA}: Should the
results be ordered in a descending order? If \code{NA} is given the order
as found in \code{object} for the \code{n} most abundant taxa is used.
(default: \code{order_descending = TRUE})}
}
\value{
A \code{ggplot2} object
}
\description{
This function plots abundance of the most abundant taxa.
}
\details{
This function plots abundance of the most abundant taxa. Abundance can be plotted as
a jitter plot, a density plot, or a point plot. By default, x-axis represents abundance
and y-axis taxa. In a jitter and point plot, each point represents abundance of
individual taxa in individual sample. Most common abundances are shown as a higher density.

A density plot can be seen as a smoothened bar plot. It visualized distribution of
abundances where peaks represent most common abundances.
}
\examples{
tse <- microbiomeDataSets::atlas1006()

# Plots the abundances of 25 most abundant taxa. Jitter plot is the default option.
plotAbundanceDensity(tse, abund_values = "counts")

# Counts relative abundances
tse <- transformSamples(tse, method = "relabundance")

# Plots the relative abundance of 10 most abundant taxa. 
# "nationality" information is used to color the points. X-axis is log-scaled.
plotAbundanceDensity(tse, layout = "jitter", abund_values = "relabundance", 
                     n = 10, colour_by = "nationality") +
    scale_x_log10() 
                     
# Plots the relative abundance of 10 most abundant taxa as a density plot.
# X-axis is log-scaled
plotAbundanceDensity(tse, layout = "density", abund_values = "relabundance",
                     n = 10 ) +
    scale_x_log10()
                     
# Plots the relative abundance of 10 most abundant taxa as a point plot.
# Point shape is changed from default (21) to 41.
plotAbundanceDensity(tse, layout = "point", abund_values = "relabundance", n = 10,
                     point_shape = 41)
                     
# Plots the relative abundance of 10 most abundant taxa as a point plot.
# In addition to colour, groups can be visualized by size and shape in point plots,
# and adjusted for point size
plotAbundanceDensity(tse, layout = "point", abund_values = "relabundance", n = 10,
                     shape_by = "sex", size_by = "time", point_size=1)

# Ordering via order_descending
plotAbundanceDensity(tse, abund_values = "relabundance", 
                     order_descending = FALSE)

# for custom ordering set order_descending = NA and order the input object
# to your wishes
plotAbundanceDensity(tse, abund_values = "relabundance",
                     order_descending = NA)

}
\author{
Leo Lahti and Tuomas Borman. Contact: \url{microbiome.github.io}
}
