% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotPrevalence.R
\name{plotPrevalence}
\alias{plotPrevalence}
\alias{plotPrevalence,SummarizedExperiment-method}
\alias{plotPrevalentAbundance}
\alias{plotPrevalentAbundance,SummarizedExperiment-method}
\alias{plotTaxaPrevalence}
\alias{plotTaxaPrevalence,SummarizedExperiment-method}
\title{Plot prevalence information}
\usage{
plotPrevalence(x, ...)

\S4method{plotPrevalence}{SummarizedExperiment}(
  x,
  detections = c(0.01, 0.1, 1, 2, 5, 10, 20)/100,
  prevalences = seq(0.1, 1, 0.1),
  abund_values = "counts",
  as_relative = TRUE,
  rank = NULL,
  BPPARAM = BiocParallel::SerialParam(),
  ...
)

plotPrevalentAbundance(x, ...)

\S4method{plotPrevalentAbundance}{SummarizedExperiment}(
  x,
  rank = taxonomyRanks(x)[1L],
  abund_values = "counts",
  as_relative = TRUE,
  colour_by = NULL,
  size_by = NULL,
  shape_by = NULL,
  label = NULL,
  facet_by = NULL,
  ...
)

plotTaxaPrevalence(x, ...)

\S4method{plotTaxaPrevalence}{SummarizedExperiment}(
  x,
  rank = taxonomyRanks(x)[1L],
  abund_values = "counts",
  detections = NULL,
  ndetections = 20,
  as_relative = TRUE,
  min_prevalence = 0,
  BPPARAM = BiocParallel::SerialParam(),
  ...
)
}
\arguments{
\item{x}{a
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
object.}

\item{detections}{Detection thresholds for absence/presence. Either an
absolutes value compared directly to the values of \code{x} or a relative
value between 0 and 1, if \code{as_relative = TRUE}.}

\item{prevalences}{Prevalence thresholds (in 0 to 1). The
required prevalence is strictly greater by default. To include the
limit, set \code{include_lowest} to \code{TRUE}.}

\item{abund_values}{a \code{character} value defining which assay data to
use. (default: \code{abund_values = "relabundance"})}

\item{as_relative}{logical scalar: Should the detection threshold be applied
on compositional (relative) abundances? Passed onto
\code{\link[mia:getPrevalence]{getPrevalence}}. (default: \code{TRUE})}

\item{rank, ...}{additional arguments
\itemize{
\item{If \code{!is.null(rank)} matching arguments are passed on to
\code{\link[=agglomerate-methods]{agglomerateByRank}}. See
\code{\link[=agglomerate-methods]{?agglomerateByRank}} for more details.
}
\item{additional arguments for plotting. See
\code{\link{mia-plot-args}} for more details i.e. call \code{help("mia-plot-args")}}
}}

\item{BPPARAM}{A
\code{\link[BiocParallel:BiocParallelParam-class]{BiocParallelParam}}
object specifying whether the UniFrac calculation should be parallelized.}

\item{colour_by}{Specification of a feature to colour points by, see the
\code{by} argument in
\code{\link[scater:retrieveFeatureInfo]{?retrieveFeatureInfo}} for
possible values. Only used with \code{layout = "point"}.}

\item{size_by}{Specification of a feature to size points by, see the
\code{by} argument in
\code{\link[scater:retrieveFeatureInfo]{?retrieveFeatureInfo}} for
possible values. Only used with \code{layout = "point"}.}

\item{shape_by}{Specification of a feature to shape points by, see the
\code{by} argument in
\code{\link[scater:retrieveFeatureInfo]{?retrieveFeatureInfo}} for
possible values. Only used with \code{layout = "point"}.}

\item{label}{a \code{logical}, \code{character} or \code{integer} vector
for selecting labels from the rownames of \code{x}. If \code{rank} is not
\code{NULL} the rownames might change. (default: \code{label = NULL})}

\item{facet_by}{Taxonomic rank to facet the plot by.
Value must be of \code{taxonomyRanks(x)}
Argument can only be used in function plotPrevalentAbundance.}

\item{ndetections}{If \code{detections} is \code{NULL}, a number of breaks
are calculated automatically. \code{as_relative} is then also regarded as
\code{TRUE}.}

\item{min_prevalence}{a single numeric value to apply as a threshold for
plotting. The threshold is applied per row and column.
(default: \code{min_prevalence = 0})}
}
\value{
A \code{ggplot2} object or \code{plotly} object, if more than one
\code{prevalences} was defined.
}
\description{
\code{plotPrevalence} and \code{plotTaxaPrevalence} visualize prevalence
information.
}
\details{
Whereas \code{plotPrevalence} procudes a line plot, \code{plotTaxaPrevalence}
returns a heatmap.

Agglomeration on different taxonomic levels is available through the
\code{rank} argument.

To exclude certain taxa, preprocess \code{x} to your liking, for example
with subsetting via \code{getPrevalentTaxa} or
\code{agglomerateByPrevalence}.
}
\examples{
data(GlobalPatterns, package = "mia")

# plotting N of prevalence exceeding taxa on the Phylum level
plotPrevalence(GlobalPatterns, rank = "Phylum")
plotPrevalence(GlobalPatterns, rank = "Phylum") + scale_x_log10()

# plotting prevalence per taxa for different detectio thresholds as heatmap
plotTaxaPrevalence(GlobalPatterns, rank = "Phylum")

# by default a continous scale is used for different detections levels, 
# but this can be adjusted
plotTaxaPrevalence(GlobalPatterns, rank = "Phylum",
                   detections = c(0, 0.001, 0.01, 0.1, 0.2))
                   
# point layout for plotTaxaPrevalence can be used to visualize by additional
# information
plotPrevalentAbundance(GlobalPatterns, rank = "Family",
                       colour_by = "Phylum") +
    scale_x_log10()

# When using function plotPrevalentAbundace, it is possible to create facets
# with 'facet_by'.
plotPrevalentAbundance(GlobalPatterns, rank = "Family",
                       colour_by = "Phylum", facet_by = "Kingdom") +
    scale_x_log10()
}
\seealso{
\code{\link[mia:getPrevalence]{getPrevalence}},
\code{\link[mia:getPrevalence]{agglomerateByPrevalence}},
\code{\link[mia:agglomerate-methods]{agglomerateByRank}}
}
